==> kubernetes-model-core-5.11.0-sources.jar: io/fabric8/kubernetes/api/model/NamedAuthInfoFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class NamedAuthInfoFluentImpl<A extends io.fabric8.kubernetes.api.model.NamedAuthInfoFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.NamedAuthInfoFluent<A>{
  public NamedAuthInfoFluentImpl() {
  }
  public NamedAuthInfoFluentImpl(io.fabric8.kubernetes.api.model.NamedAuthInfo instance) {
    this.withName(instance.getName()); 
    this.withUser(instance.getUser()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String name;
  private io.fabric8.kubernetes.api.model.AuthInfoBuilder user;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildUser instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.AuthInfo getUser() {
    return this.user!=null?this.user.build():null;
  }
  public io.fabric8.kubernetes.api.model.AuthInfo buildUser() {
    return this.user!=null?this.user.build():null;
  }
  public A withUser(io.fabric8.kubernetes.api.model.AuthInfo user) {
    _visitables.get("user").remove(this.user);
    if (user!=null){ this.user= new io.fabric8.kubernetes.api.model.AuthInfoBuilder(user); _visitables.get("user").add(this.user);} return (A) this;
  }
  public java.lang.Boolean hasUser() {
    return this.user != null;
  }
  public io.fabric8.kubernetes.api.model.NamedAuthInfoFluent.UserNested<A> withNewUser() {
    return new io.fabric8.kubernetes.api.model.NamedAuthInfoFluentImpl.UserNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.NamedAuthInfoFluent.UserNested<A> withNewUserLike(io.fabric8.kubernetes.api.model.AuthInfo item) {
    return new io.fabric8.kubernetes.api.model.NamedAuthInfoFluentImpl.UserNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.NamedAuthInfoFluent.UserNested<A> editUser() {
    return withNewUserLike(getUser());
  }
  public io.fabric8.kubernetes.api.model.NamedAuthInfoFluent.UserNested<A> editOrNewUser() {
    return withNewUserLike(getUser() != null ? getUser(): new io.fabric8.kubernetes.api.model.AuthInfoBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.NamedAuthInfoFluent.UserNested<A> editOrNewUserLike(io.fabric8.kubernetes.api.model.AuthInfo item) {
    return withNewUserLike(getUser() != null ? getUser(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    NamedAuthInfoFluentImpl that = (NamedAuthInfoFluentImpl) o;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (user != null ? !user.equals(that.user) :that.user != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(name,  user,  additionalProperties,  super.hashCode());
  }
  public class UserNestedImpl<N> extends io.fabric8.kubernetes.api.model.AuthInfoFluentImpl<io.fabric8.kubernetes.api.model.NamedAuthInfoFluent.UserNested<N>> implements io.fabric8.kubernetes.api.model.NamedAuthInfoFluent.UserNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    UserNestedImpl(io.fabric8.kubernetes.api.model.AuthInfo item) {
      this.builder = new io.fabric8.kubernetes.api.model.AuthInfoBuilder(this, item);
    }
    UserNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.AuthInfoBuilder(this);
    }
    io.fabric8.kubernetes.api.model.AuthInfoBuilder builder;
    public N and() {
      return (N) NamedAuthInfoFluentImpl.this.withUser(builder.build());
    }
    public N endUser() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-core-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/NamedAuthInfoFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class NamedAuthInfoFluentImpl<A extends io.fabric8.kubernetes.api.model.NamedAuthInfoFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.NamedAuthInfoFluent<A>{
  public NamedAuthInfoFluentImpl() {
  }
  public NamedAuthInfoFluentImpl(io.fabric8.kubernetes.api.model.NamedAuthInfo instance) {
    this.withName(instance.getName()); 
    this.withUser(instance.getUser()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private java.lang.String name;
  private io.fabric8.kubernetes.api.model.AuthInfoBuilder user;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  public java.lang.String getName() {
    return this.name;
  }
  public A withName(java.lang.String name) {
    this.name=name; return (A) this;
  }
  public java.lang.Boolean hasName() {
    return this.name != null;
  }
  
  /**
   * Method is deprecated. use withName instead.
   */
  @java.lang.Deprecated
  public A withNewName(java.lang.String arg0) {
    return (A)withName(new String(arg0));
  }
  
  /**
   * This method has been deprecated, please use method buildUser instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.AuthInfo getUser() {
    return this.user!=null?this.user.build():null;
  }
  public io.fabric8.kubernetes.api.model.AuthInfo buildUser() {
    return this.user!=null?this.user.build():null;
  }
  public A withUser(io.fabric8.kubernetes.api.model.AuthInfo user) {
    _visitables.get("user").remove(this.user);
    if (user!=null){ this.user= new io.fabric8.kubernetes.api.model.AuthInfoBuilder(user); _visitables.get("user").add(this.user);} return (A) this;
  }
  public java.lang.Boolean hasUser() {
    return this.user != null;
  }
  public io.fabric8.kubernetes.api.model.NamedAuthInfoFluent.UserNested<A> withNewUser() {
    return new io.fabric8.kubernetes.api.model.NamedAuthInfoFluentImpl.UserNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.NamedAuthInfoFluent.UserNested<A> withNewUserLike(io.fabric8.kubernetes.api.model.AuthInfo item) {
    return new io.fabric8.kubernetes.api.model.NamedAuthInfoFluentImpl.UserNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.NamedAuthInfoFluent.UserNested<A> editUser() {
    return withNewUserLike(getUser());
  }
  public io.fabric8.kubernetes.api.model.NamedAuthInfoFluent.UserNested<A> editOrNewUser() {
    return withNewUserLike(getUser() != null ? getUser(): new io.fabric8.kubernetes.api.model.AuthInfoBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.NamedAuthInfoFluent.UserNested<A> editOrNewUserLike(io.fabric8.kubernetes.api.model.AuthInfo item) {
    return withNewUserLike(getUser() != null ? getUser(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    NamedAuthInfoFluentImpl that = (NamedAuthInfoFluentImpl) o;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (user != null ? !user.equals(that.user) :that.user != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(name,  user,  additionalProperties,  super.hashCode());
  }
  public class UserNestedImpl<N> extends io.fabric8.kubernetes.api.model.AuthInfoFluentImpl<io.fabric8.kubernetes.api.model.NamedAuthInfoFluent.UserNested<N>> implements io.fabric8.kubernetes.api.model.NamedAuthInfoFluent.UserNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    UserNestedImpl(io.fabric8.kubernetes.api.model.AuthInfo item) {
      this.builder = new io.fabric8.kubernetes.api.model.AuthInfoBuilder(this, item);
    }
    UserNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.AuthInfoBuilder(this);
    }
    io.fabric8.kubernetes.api.model.AuthInfoBuilder builder;
    public N and() {
      return (N) NamedAuthInfoFluentImpl.this.withUser(builder.build());
    }
    public N endUser() {
      return and();
    }
    
  }
  
}
